#define REG_NOOP   0x00
#define REG_DIGIT0 0x01
#define REG_DIGIT1 0x02
#define REG_DIGIT2 0x03
#define REG_DIGIT3 0x04
#define REG_DIGIT4 0x05
#define REG_DIGIT5 0x06
#define REG_DIGIT6 0x07
#define REG_DIGIT7 0x08
#define REG_DECODEMODE  0x09
#define REG_INTENSITY   0x0A
#define REG_SCANLIMIT   0x0B
#define REG_SHUTDOWN    0x0C
#define REG_DISPLAYTEST 0x0F
#define CS 10
#define SL A3
#define UP B11110111
#define DOWN B01111111
#define LEFT B11101111
#define RIGHT B11111110
#define START B11011111
#define OPTIONS B10111111
#define EXIT B11111101
#define NOTHING B11111111

#include <EEPROM.h>
#include <math.h>
#include <SPI.h>
#include <avr/sleep.h>

byte x = 4;
byte y = 4;
/*
unsigned long img[40] = {
 199618655, 4171782085, 199520351, 524288, 4226152415, 2290684996, 4226152415, 524288,
 5400927, 36194257, 65384543, 524288, 3271948248, 2181629008, 4226152415, 524288,
 4194660368, 2819182592, 2282082304, 524298, 65339908, 36176906, 44303296, 36175903,
 2078668753, 2148078933, 2078626897, 44650527, 3131379712, 2863207935, 3936702721, 65623365,
 161081641, 2884179217, 2326090025, 57234757, 2191855873, 65664511, 262144, 920350134
 };
 */
unsigned long lastPress = 0;
byte game = 0;
byte buffer[8] = {
  0, 0, 0, 0, 0, 0, 0, 0};
int xoffset;
int yoffset;
int zoffset;
byte brightLevel;
byte buttons;
unsigned long lastMove = 0;

// Hackaday Easter egg
byte konami[10] = {
  UP, UP, DOWN, DOWN, LEFT, RIGHT, LEFT, RIGHT, OPTIONS, START};
byte egg = 0;
byte hacked = 0;

#include "display.h"
#include "games.h"

void calibrateXY() {
  unsigned x0 = 0;
  unsigned y0 = 0;
  for (byte i = 0; i < 64; i++) {
    x0 += analogRead(0);
    y0 += analogRead(1);
  }
  xoffset = x0 / 64;
  yoffset = y0 / 64;  
}

void calibrateZ() {
  unsigned z0 = 0;
  for (byte i = 0; i < 64; i++) {
    z0 += analogRead(2);
  }
  zoffset = z0 / 64;
}

void check_battery() {
  unsigned voltage = 0;
  for (byte i = 0; i < 32; i++) {
    voltage += analogRead(5);
  }
  if (voltage < 26500)
    turn_off();
}

void turn_off() {
  sendToMatrix(REG_INTENSITY, 0);
  sendToMatrix(REG_SHUTDOWN, 0);
  digitalWrite(SL, LOW);
  ADCSRA = 0;
  PRR = B11111111;  
  set_sleep_mode(SLEEP_MODE_PWR_DOWN);
  sleep_enable();
  cli(); // switch interrupts off while messing with their settings  
  PCICR = B00000101; // Enable PCINT0 and PCINT2 interrupts
  PCMSK0 = B00000011; // Interrupt on PCINT0 and PCINT1
  PCMSK2 = B11111000; // Interrupt on PCINT19..PCINT23
  sei(); // turn interrupts back on
  sleep_mode();

  PRR = 0;  
  ADCSRA = B10010111;
  digitalWrite(SL, HIGH);
  sendToMatrix(REG_SHUTDOWN, 1);
  game = 10; // battery
}

ISR(PCINT0_vect) {
  sleep_disable(); // first thing after waking from sleep: disable sleep
  cli(); // switch interrupts off while messing with their settings  
  PCICR = B00000000; // Disable PCINT0 and PCINT2 interrupt
  PCMSK0 = B00000000; // Clear Pin Change Mask Register 0
  PCMSK2 = B00000000; // Clear Pin Change Mask Register 2
  sei(); // turn interrupts back on
}

ISR(PCINT2_vect) {
  sleep_disable(); // first thing after waking from sleep: disable sleep
  cli(); // switch interrupts off while messing with their settings  
  PCICR = B00000000; // Disable PCINT0 and PCINT2 interrupt
  PCMSK0 = B00000000; // Clear Pin Change Mask Register 0
  PCMSK2 = B00000000; // Clear Pin Change Mask Register 2
  sei(); // turn interrupts back on
}

void loadSettings() {
  xoffset = EEPROM.read(0) + word(EEPROM.read(1) << 8);
  yoffset = EEPROM.read(2) + word(EEPROM.read(3) << 8);
  zoffset = EEPROM.read(4) + word(EEPROM.read(5) << 8);
  brightLevel = EEPROM.read(6) & B00001111;
}

byte selGame = 0;
# define NUM_OF_GAMES 11

void menu() {
  if (buttons != NOTHING && long(millis() - lastPress) > 75) {
    switch (buttons) {
    case UP:
    case LEFT:
      if (selGame < 2)
        selGame = NUM_OF_GAMES;
      else
        selGame--;
      break;
    case DOWN:
    case RIGHT:
      if (selGame == NUM_OF_GAMES)
        selGame = 1;
      else
        selGame++;
      break;
    case EXIT:
      selGame = 0;
      break;
    case START:
      clearBuffer();
      clearMatrix();
      lastMove = millis();
      game = selGame;
      return;
    }
  }
  switch (selGame) {
  case 0: // menu
    writeRows(69, 160, 66, 0, 255, 129, 129, 255);
    break;
  case 1: // ball
    writeRows(255, 0, 48, 120, 120, 48, 0, 0);
    break;
  case 2: // bubble
    writeRows(0, 0, 12, 18, 18, 12, 129, 126);
    break;
  case 3: // dice
    writeRows(127, 193, 209, 193, 197, 193, 255, 254);
    break;
  case 4: // maze
    writeRows(223, 81, 93, 65, 215, 20, 119, 81);
    break;
  case 5: // snake
    writeRows(127, 128, 126, 1, 30, 32, 48, 48);
    break;
  case 6: // paint
    writeRows(254, 130, 81, 127, 32, 32, 64, 64);
    break;
  case 7: // image viewer
    writeRows(255, 169, 137, 149, 137, 149, 129, 255);
    break;
  case 8: // bargraph
    writeRows(255, 85, 85, 81, 81, 17, 17, 1);
    break;
  case 9: // calibrate
    writeRows(129, 90, 36, 90, 90, 36, 90, 129);
    break;
  case 10: // battery
    writeRows(126, 66, 126, 66, 66, 66, 126, 24);
    break;
  case 11: // brightness
    writeRows(145, 66, 24, 37, 164, 24, 66, 137);
    break;
  }
}

void setup() {
  DDRB = B00111100;
  DDRC = B00000000;
  DDRD = B00000000;
  PORTB = B00000111;
  PORTC = B00000000;
  PORTD = B11111000;
  analogReference(EXTERNAL);
  randomSeed(analogRead(0) + (analogRead(1) << 4) + (analogRead(2) << 8));
  digitalWrite(SL, HIGH);
  SPI.setClockDivider(SPI_CLOCK_DIV2);
  SPI.begin();
  loadSettings();
  sendToMatrix(REG_DECODEMODE, 0);
  sendToMatrix(REG_INTENSITY, brightLevel);
  sendToMatrix(REG_SCANLIMIT, 7);
  sendToMatrix(REG_SHUTDOWN, 1);
  sendToMatrix(REG_DISPLAYTEST, 0);
  clearMatrix();
  //Serial.begin(9600);
}


void loop() {
  buttons = (PIND | B00000111) & (PINB | B11111100);
  
  if (buttons != NOTHING) {
    if (long(millis() - lastPress) > 75) {
      if (buttons == konami[egg]) {
        //Serial.println(egg);
        if (egg == 9) {
          egg = 0;
          hacked = 1 - hacked;
        }
        else {
          egg++;
        }
      }
      else {
        egg = 0;
      }
    }
  }

  switch (game) {
  case 0:
    menu();
    break;
  case 1:
    ball();
    break;
  case 2:
    bubble();
    break;    
  case 3:
    dice();
    break;    
  case 4:
    maze();
    break;    
  case 5:
    snake();
    break;    
  case 6:
    paint();
    break;    
  case 7:
    imgView();
    break;    
  case 8:
    bargraph();
    break;    
  case 9:
    calibrate();
    break;    
  case 10:
    battery();
    break;    
  case 11:
    brightness();
    break;    
  }
  
  if (buttons != NOTHING) {
    lastPress = millis();
  }

  check_battery();
}


