float sx = 0;
float sy = 0;
float vx = 0;
float vy = 0;
boolean hit = true;
boolean terc = false;
byte tercx = 3;
byte tercy = 3;

void ball() {
  long dt = millis() - lastMove;
  lastMove = millis();
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      xoffset = EEPROM.read(0) + word(EEPROM.read(1) << 8);
      yoffset = EEPROM.read(2) + word(EEPROM.read(3) << 8);
      game = 0;
      break;
    case START:
      calibrateXY();
      break;
    case OPTIONS:
      terc = !terc;
      break;
    }
  }

  float ax = -0.000002 * (analogRead(0) - xoffset);
  float ay = -0.000002 * (analogRead(1) - yoffset);
  vx += ax * dt;
  vy += ay * dt;
  sx += vx * dt + ax * dt * dt / 2;
  sy += vy * dt + ay * dt * dt / 2;
  if (sx < -4) {
    sx = -4;
    vx *= -0.6;
  }
  if (sx > 4) {
    sx = 4;
    vx *= -0.6;
  }
  if (sy < -4) {
    sy = -4;
    vy *= -0.6;
  }
  if (sy > 4) {
    sy = 4;
    vy *= -0.6;
  }
  byte kulx = constrain(4 + sx, 0, 7);
  byte kuly = constrain(4 + sy, 0, 7);
  if (terc) {
    if (hit) {
      do {
        tercx = random(6) + 1;
        tercy = random(6) + 1;
      }
      while (abs(tercx - kulx) + abs(tercy - kuly) < 4);
      hit = false;
    }
    if (tercx == kulx && tercy == kuly)
      hit = true;
  }
  for (byte i = 0; i < 8; i++) {
    sendToMatrix(i + 1, ((i == kuly) ? B00000001 << kulx : B00000000)
      | ((terc && millis() & B00100000 && i == tercy) ? B00000001 << tercx : B00000000));
  }
}

void bubble() {
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      xoffset = EEPROM.read(0) + word(EEPROM.read(1) << 8);
      yoffset = EEPROM.read(2) + word(EEPROM.read(3) << 8);
      zoffset = EEPROM.read(4) + word(EEPROM.read(5) << 8);
      game = 0;
      break;
    case START:
      calibrateXY();
      break;
    case OPTIONS:
      calibrateZ();
      break;
    }
  }
  unsigned x0 = 0;
  unsigned y0 = 0;
  unsigned z0 = 0;
  for (byte i = 0; i < 64; i++) {
    x0 += analogRead(0);
    y0 += analogRead(1);
    z0 += analogRead(2);
  }
  int gx = int(x0 / 64) - xoffset;
  int gy = int(y0 / 64) - yoffset;
  int gz = int(z0 / 64) - zoffset;
  float sx = 12 * atan2(gx, gz);
  float sy = 12 * atan2(gy, gz);
  moveTo(constrain(4 + sx, 0, 7), constrain(4 + sy, 0, 7));
  delay(10);
}

void bargraph() {
  if (long(millis() - lastPress) > 75) {  
    switch (buttons) {
    case EXIT:
      xoffset = EEPROM.read(0) + word(EEPROM.read(1) << 8);
      yoffset = EEPROM.read(2) + word(EEPROM.read(3) << 8);
      zoffset = EEPROM.read(4) + word(EEPROM.read(5) << 8);
      game = 0;
      break;
    case START:
      calibrateXY();
      break;
    case OPTIONS:
      calibrateZ();
      break;
    }
  }
  unsigned x0 = 0;
  unsigned y0 = 0;
  unsigned z0 = 0;
  for (byte i = 0; i < 64; i++) {
    x0 += analogRead(0);
    y0 += analogRead(1);
    z0 += analogRead(2);
  }
  char bx = constrain(0.025 * (int(x0 / 64) - xoffset), -8, 8);
  char by = constrain(0.025 * (int(y0 / 64) - yoffset), -8, 8);
  char bz = constrain(0.025 * (int(z0 / 64) - zoffset), -8, 8);
  clearBuffer();
  clearMatrix();

  if (bx > 0)
    writeRect(0, 0, 1, bx - 1);
  else if (bx < 0)
    writeRect(0, 8 + bx, 1, 7);
  if (by > 0)
    writeRect(3, 0, 4, by - 1);
  else if (by < 0)
    writeRect(3, 8 + by, 4, 7);
  if (bz > 0)
    writeRect(6, 0, 7, bz - 1);
  else if (bz < 0)
    writeRect(6, 8 + bz, 7, 7);
  delay(10);
}

//dice
unsigned xk;
unsigned yk;
unsigned zk;
unsigned cnt = 0;
float spd = 0;

void dice() {
  switch (buttons) {
  case START:
    xk = 21 * xoffset;
    yk = 21 * yoffset;
    zk = 21 * zoffset;
    break;
  case EXIT:
    game = 0;
    break;
  }
  unsigned x0 = 0;
  unsigned y0 = 0;
  unsigned z0 = 0;
  for (byte i = 0; i < 21; i++) {
    x0 += analogRead(0);
    y0 += analogRead(1);
    z0 += analogRead(2);
  }
  spd = max(0.99 * spd, 0.9 * spd + 0.000396 * (abs(int(x0 - xk)) + abs(int(y0 - yk)) + abs(int(z0 - zk))));
  if (spd > 5)
    cnt += spd * spd;
  else
    cnt = 0;
  xk = 0.9 * xk + 0.1 * x0;
  yk = 0.9 * yk + 0.1 * y0;
  zk = 0.9 * zk + 0.1 * z0;
  /*  Serial.print(spd);
   Serial.print(" ");
   Serial.println(cnt);*/
  if (cnt > 1000) {
    switch (random(6 + hacked)) {
    case 0:
      writeRows(0, 0, 0, 24, 24, 0, 0, 0);
      break;
    case 1:
      writeRows(192, 192, 0, 0, 0, 0, 3, 3);
      break;
    case 2:
      writeRows(192, 192, 0, 24, 24, 0, 3, 3);
      break;
    case 3:
      writeRows(195, 195, 0, 0, 0, 0, 195, 195);
      break;
    case 4:
      writeRows(195, 195, 0, 24, 24, 0, 195, 195);
      break;
    case 5:
      writeRows(195, 195, 0, 195, 195, 0, 195, 195);
      break;
    case 6: // easter egg
      writeRows(195, 195, 0, 219, 219, 0, 195, 195);
      break;
    }
    cnt = 0;
    delay(10);
  }
}

void calibrate() {
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      game = 0;
      break;
    case START:
      calibrateXY();
      EEPROM.write(0, xoffset & 0xFF);
      EEPROM.write(1, (xoffset >> 8) & 0xFF);
      EEPROM.write(2, yoffset & 0xFF);
      EEPROM.write(3, (yoffset >> 8) & 0xFF);
      break;
    case OPTIONS:
      calibrateZ();
      EEPROM.write(4, zoffset & 0xFF);
      EEPROM.write(5, (zoffset >> 8) & 0xFF);
      break;
    }
  }
  writeRows(216, 218, 2, 229, 32, 69, 130, 229);
}

void battery() {
  switch (buttons) {
  case EXIT:
    game = 0;
    break;
  }
  unsigned voltage = 0;
  for (byte i = 0; i < 64; i++) {
    voltage += analogRead(5);
  }
  sendToMatrix(1, 126);
  for (byte i = 2; i < 7; i++)
    sendToMatrix(i, (voltage < 48116 + 2876 * i) ? 66 : 126);
  sendToMatrix(7, 126);
  sendToMatrix(8, 24);
}

void brightness() {
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      game = 0;
      break;
    case DOWN:
    case LEFT:
      if (brightLevel)
        brightLevel--;
      break;
    case UP:
    case RIGHT:
      if (brightLevel < 15)
        brightLevel++;
      break;
    case OPTIONS:
      EEPROM.write(6, brightLevel);
      break;
    }
  }
  sendToMatrix(REG_INTENSITY, brightLevel);
  writeRows(145, 66, 24, 61, 188, 24, 66, 137);
}

char blx = 32;
char bly = 32;
char posx = 3;
char posy = 3;
char destx = 16;
char desty = 16;
char accx = 3;
char accy = 3;
//byte frame = 0;
boolean plan = false;
boolean found = true;
boolean bContr = true;
unsigned long maze1[63] = {
  4294967295, 2148007937, 2527717303, 4210440337, 2726646646, 2650593867, 2471011226, 3894881445,
  2527644394, 3554554379, 2886765940, 3354359095, 2584302925, 3984362145, 2864756018, 2438403551,
  3937221908, 2796733163, 2638605636, 3240636727, 2940970604, 2962283411, 3610072376, 3383174287,
  2639846568, 3327017847, 2494934604, 2610493863, 2837611352, 3998964811, 2304061652, 4121333555,
  2536880874, 2697511437, 2361236700, 3611435587, 2488983449, 3953443023, 3563916888, 2670932903,
  2708137772, 3423375815, 3117504308, 2256492569, 3166836402, 3275350991, 2865145364, 3035763063,
  3565989544, 2602936493, 3068998322, 3226621707, 3175983306, 2804328051, 2283022780, 4141601927,
  2829655468, 2412110419, 3107804436, 3296857583, 3187538746, 2147745921, 4294967295
};

unsigned long maze2[63] = {
  4294967295, 2172649609, 3694489398, 2799677843, 2793941800, 3715614831, 2861839680, 2449708735,
  2799713098, 3992904033, 2568390094, 2458221619, 3039384282, 3990260585, 2286237010, 3342390559,
  3026488944, 2614584071, 2501380780, 3832462067, 2509313612, 4217356583, 2756718228, 2544870363,
  3029652562, 2286050921, 4290231261, 2153007141, 2315321728, 4210816255, 2147617024, 4272729563,
  2161132582, 3949834203, 2852260096, 2179708127, 4263076272, 2189690885, 3984455677, 3467142041,
  2838989922, 3046118919, 2859035096, 3392089195, 2463418706, 4013045405, 2422597042, 2609667119,
  2989183396, 3453595217, 3646229398, 2393301227, 2980683532, 3629959669, 2777765190, 3067033123,
  2299807979, 3950227089, 2857247146, 2913065071, 3027195868, 2181046273, 4294967295
};

void mazePart(byte mx, byte my) {
  for (byte i = 0; i < 8; i++) {
    byte walls = ((hacked) ? maze2[my + i] : maze1[my + i]) >> ((mx + ((my + i) & B00000001)) >> 1);
    buffer[i] = (((my + i) & B00000001) ? B00000000 : B01010101 << (mx & B00000001));
    buffer[i] |= (walls & B00000001 | (walls & B00000010) << 1 | (walls & B00000100) << 2 | (walls & B00001000) << 3) << ((my + i + mx + 1) & B00000001);
    //sendToMatrix(i + 1, buffer[i]);  
  }
}

void maze() {
  char dx = 0;
  char dy = 0;
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      game = 0;
      break;
    case START:
      plan = !plan;
      break;
    case OPTIONS:
      bContr = !bContr;
      break;
    }
  }

  if (found) {
    do {
      destx = random(31) * 2 + 1;
      desty = random(31) * 2 + 1;
    }
    while (abs(destx - blx - posx) + abs(desty - bly - posy) < 32);
    found = false;
  }

  if (plan) {
    byte rowDest = (desty - 1) / 7.6;
    byte rowPos = (bly + posy - 1) / 7.6;    
    for (byte i = 0; i < 8; i++) {
      sendToMatrix(i + 1, ((millis() & B00100000 && i == rowPos) ? B00000001 << byte((blx + posx - 1) / 7.6) : B00000000)
        | ((millis() & B01000000 && i == rowDest) ? B00000001 << byte((destx - 1) / 7.6) : B00000000));
    }
  }

  else {
    mazePart(blx, bly);
    for (byte i = 0; i < 8; i++) {
      sendToMatrix(i + 1, buffer[i] | ((millis() & B00100000 && i == posy) ? B00000001 << posx : B00000000)
        | ((millis() & B01000000 && i == desty - bly && destx >= blx) ? B00000001 << destx - blx : B00000000));
    }
    if (blx + posx == destx && bly + posy == desty)
      found = true;

    if (bContr) {
      if (long(millis() - lastMove) > 75) {
        switch (buttons) {
        case UP:
          dy = 1;
          break;
        case DOWN:
          dy = -1;
          break;
        case LEFT:
          dx = -1;
          break;
        case RIGHT:
          dx = 1;
          break;
        }
        if (dx || dy)
          lastMove = millis();
      }
    }

    else {
      long dt = millis() - lastMove;
      lastMove = millis();
      int x0 = 0;
      int y0 = 0;
      for (byte i = 0; i < 32; i++) {
        x0 += analogRead(0);
        y0 += analogRead(1);
      }
      accx -= ((x0 / 32 - xoffset) * dt) >> 7;
      accy -= ((y0 / 32 - yoffset) * dt) >> 7;

      if (accx > 64) {
        dx = 1;
        accx -= 64;
      }
      if (accx < -64) {
        dx = -1;
        accx += 64;
      }  
      if (accy > 64) {
        dy = 1;
        accy -= 64;
      }
      if (accy < -64) {
        dy = -1;
        accy += 64;
      }
    }

    if (!(buffer[posy + dy] & B00000001  << (posx + dx))) {
      if (blx + dx < 0 || blx + dx > 55 || posx < 3 || posx > 4)
        posx += dx;
      else
        blx += dx;
      if (bly + dy < 0 || bly + dy > 55 || posy < 3 || posy > 4)
        posy += dy;
      else
        bly += dy;
    }
    else {
      accx = constrain(accx, -64, 64);
      accy = constrain(accy, -64, 64);
    }
  }
}

byte snakeTail[16];
byte snakePos = 27;
byte foodPos;
boolean pause = false;
boolean snakeFound = true;
byte snakeDir = 1;
byte snakeLen = 1;

byte dirToPos(byte pos, byte dir) {
  switch (dir) {
  case 0:
    if (pos < 56)
      return pos + 8;
    else
      return pos - 56;
  case 3:
    if (pos > 7)
      return pos - 8;
    else
      return pos + 56;
  case 2:
    if (pos & B00000111)
      return pos - 1;
    else
      return pos + 7;
    break;
  case 1:
    if ((pos & B00000111) == 7)
      return pos - 7;
    else
      return pos + 1;
    break;
  }
}

void snake() {
  char dx = 0;
  char dy = 0;
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      game = 0;
      break;
    case START:
      pause = !pause;
      break;
    case OPTIONS:
      bContr = !bContr;
      break;
    }
  }

  byte myPos = snakePos;
  clearBuffer();
  for (byte i = 0; i < snakeLen - 1; i++) {
    myPos = dirToPos(myPos, ~(snakeTail[i >> 2] >> ((i & B00000011) << 1)) & B00000011);
    buffer[myPos >> 3] |= 1 << (myPos & B00000111);
  }
  if (buffer[snakePos >> 3] & (1 << (snakePos & B00000111)))
    snakeLen = 1;
  else
    buffer[snakePos >> 3] |= 1 << (snakePos & B00000111);
  if (snakeFound) {
    do {
      foodPos = random(64);
    }
    while (buffer[foodPos >> 3] & (1 << (foodPos & B00000111)));
    snakeFound = false;
  }
  if (millis() & B00100000)
    buffer[foodPos >> 3] |= 1 << (foodPos & B00000111);
  updateMatrix();
  byte currentDir = snakeTail[0] & B00000011;
  if (bContr) {
    switch (buttons) {
    case UP:
      if (currentDir != 3)
        snakeDir = 0;
      break;
    case DOWN:
      if (currentDir != 0)
        snakeDir = 3;
      break;
    case LEFT:
      if (currentDir != 1)
        snakeDir = 2;
      break;
    case RIGHT:
      if (currentDir != 2)
        snakeDir = 1;
      break;
    }
  }

  else {
    int x0 = 0;
    int y0 = 0;
    for (byte i = 0; i < 32; i++) {
      x0 += analogRead(0);
      y0 += analogRead(1);
    }
    if (abs(y0 / 32 - yoffset) > abs(x0 / 32 - xoffset)) {
      if (currentDir != 0 && y0 / 32 - yoffset > 64)
        snakeDir = 3;
      else if (currentDir != 3 && y0 / 32 - yoffset < -64)
        snakeDir = 0;
    }
    else {
      if (currentDir != 2 && x0 / 32 - xoffset < -64)
        snakeDir = 1;
      else if (currentDir != 1 && x0 / 32 - xoffset > 64)
        snakeDir = 2;
    }
  }

  if (pause)
    lastMove = millis();

  if (long(millis() - lastMove) > 256) {
    lastMove = millis();
    if (snakePos == foodPos) {
      snakeFound = true;
      snakeLen++;
    }
    snakePos = dirToPos(snakePos, snakeDir);
    for (char i = (snakeLen - 1) >> 2; i >= 0; i--) {
      snakeTail[i] = (snakeTail[i] << 2) | ((i) ? (snakeTail[i - 1] >> 6) : snakeDir);
    }
    clearBuffer();
  }
}

byte paintMenu = 0;
byte img1[8] = {
  0, 0, 0, 0, 0, 0, 0, 0};
byte img2[8] = {
  0, 0, 0, 0, 0, 0, 0, 0};
byte buffer1[8] = {
  0, 0, 0, 0, 0, 0, 0, 0};
byte buffer2[8] = {
  0, 0, 0, 0, 0, 0, 0, 0};
byte paintx = 3;
byte painty = 3;
byte color = 3;
char imgNum = -1;
byte waiting = 32;
byte counter = 0;

void refresh() {
  counter++;
  switch (counter) {
  case 2:
    for (byte i = 0; i < 8; i++) {
      sendToMatrix(i + 1, buffer1[i]);
    }
    break;
  case 1:
  case 4:
  case 7:
    for (byte i = 0; i < 8; i++) {
      sendToMatrix(i + 1, buffer2[i]);
    }
    break;
  case 9:
    counter = 0;
    break;
  default:
    for (byte i = 0; i < 8; i++) {
      sendToMatrix(i + 1, buffer1[i] & buffer2[i]);
    }
  }
}

void loadImg(byte num) {
  for (byte i = 0; i < 8; i++) {
    img1[i] = EEPROM.read(32 + 16 * num + i + 64 * hacked);
    img2[i] = EEPROM.read(40 + 16 * num + i + 64 * hacked);
  }
}

void saveImg(byte num) {
  for (byte i = 0; i < 8; i++) {
    EEPROM.write(32 + 16 * num + i + 64 * hacked, img1[i]);
    EEPROM.write(40 + 16 * num + i + 64 * hacked, img2[i]);
  }
}

void paint() {
  attachInterrupt(0, refresh, FALLING);
  switch (paintMenu) {

  case 0: 
    {
      char dx = 0;
      char dy = 0;
      if (long(millis() - lastPress) > 75) {
        switch (buttons) {
        case EXIT:
          detachInterrupt(0);
          waiting = 32;
          game = 0;
          break;
        case OPTIONS:
          paintMenu = 1;
          break;
        }
      }
      if (long(millis() - lastMove) > 200 && !waiting) {
        switch (buttons | B00100000) {
        case UP:
          dy = 1;
          break;
        case DOWN:
          dy = -1;
          break;
        case LEFT:
          dx = -1;
          break;
        case RIGHT:
          dx = 1;
          break;
        case UP & LEFT:
          dx = -1;
          dy = 1;
          break;
        case DOWN & LEFT:
          dx = -1;
          dy = -1;
          break;
        case UP & RIGHT:
          dx = 1;
          dy = 1;
          break;
        case DOWN & RIGHT:
          dx = 1;
          dy = -1;
          break;
        }
        if (dx || dy)
          lastMove = millis();
      }
      paintx = constrain(paintx + dx, 0, 7);
      painty = constrain(painty + dy, 0, 7);
      boolean painting = !(buttons & B00100000);
      if (painting && !waiting) {
        bitWrite(img1[painty], paintx, color & B00000001);
        bitWrite(img2[painty], paintx, color & B00000010);
      }
      else if (buttons == NOTHING && waiting) {
        waiting--;
      }


      for (byte i = 0; i < 8; i++) {
        byte line1 = img1[i];
        byte line2 = img2[i];
        if (i == painty && !painting) {
          bitWrite(line1, paintx, (millis() & B00100000));
          bitWrite(line2, paintx, (millis() & B00100000));
        }
        buffer1[i] = line1;
        buffer2[i] = line2;
      }
      break;
    }
  case 1: 
    {
      bufferRows(buffer1, 229, 167, 0, 61, 27, 7, 3, 1);
      bufferRows(buffer2, 229, 167, 0, 188, 216, 224, 192, 128);
      if (long(millis() - lastPress) > 75) {
        switch (buttons) {
        case UP:
          color = 0;
          paintMenu = 0;
          break;
        case LEFT:
          color = 1;
          paintMenu = 0;
          break;
        case DOWN:
          color = 3;
          paintMenu = 0;
          break;
        case RIGHT:
          color = 2;
          paintMenu = 0;
          break;
        case EXIT:
          paintMenu = 0;
          break;
        case START:
          paintMenu = 2;
          break;
        case OPTIONS:
          paintMenu = 3;
          break;
        }
      }
      waiting = 32;
      break;
    }
  case 2: 
    {
      byte rowa = (imgNum == 3) ? 60 : 36;
      byte rowb = (imgNum == 2) ? 194 : (imgNum == 1) ? 67: 66;
      byte rowc = (imgNum == 0) ? 60 : 36;
      bufferRows(buffer1, rowa, 24, 129, rowb, rowb, 129, 24, rowc);
      bufferRows(buffer2, 36, 24, 129, 90, 90, 129, 24, 36);
      if (long(millis() - lastPress) > 75) {
        switch (buttons) {
        case UP:
          loadImg(0);
          imgNum = 0;
          paintMenu = 0;
          break;
        case LEFT:
          loadImg(1);
          imgNum = 1;
          paintMenu = 0;
          break;
        case RIGHT:
          loadImg(2);
          imgNum = 2;
          paintMenu = 0;
          break;
        case DOWN:
          loadImg(3);
          imgNum = 3;
          paintMenu = 0;
          break;
        case EXIT:
          paintMenu = 1;
          break;
        case START:
          if (imgNum != -1)
            loadImg(imgNum);
          paintMenu = 0;
          waiting = 32;
          break;
        case OPTIONS:
          for (byte i = 0; i < 8; i++) {
            img1[i] = 0;
            img2[i] = 0;
          }
          imgNum = -1;
          paintMenu = 0;
          break;
        }
      }
      waiting = 32;
      break;
    }
  case 3: 
    {
      byte rowa = (imgNum == 3) ? 60 : 36;
      byte rowb = (imgNum == 2) ? 193 : (imgNum == 1) ? 131: 129;
      byte rowc = (imgNum == 0) ? 60 : 36;
      bufferRows(buffer1, 60, rowa, 195, rowb, rowb, 195, rowc, 60);
      bufferRows(buffer2, 60, 36, 195, 153, 153, 195, 36, 60);
      if (long(millis() - lastPress) > 75) {
        switch (buttons) {
        case UP:
          saveImg(0);
          imgNum = 0;
          paintMenu = 0;
          break;
        case LEFT:
          saveImg(1);
          imgNum = 1;
          paintMenu = 0;
          break;
        case RIGHT:
          saveImg(2);
          imgNum = 2;
          paintMenu = 0;
          break;
        case DOWN:
          saveImg(3);
          imgNum = 3;
          paintMenu = 0;
          break;
        case EXIT:
          paintMenu = 1;
          break;
        case START:
          paintMenu = 0;
          break;
        case OPTIONS:
          saveImg(imgNum);
          paintMenu = 0;
          break;
        }
      }
      waiting = 32;
      break;
    }
  }
}

void imgView() {
  attachInterrupt(0, refresh, FALLING);
  if (long(millis() - lastPress) > 75) {
    switch (buttons) {
    case EXIT:
      detachInterrupt(0);
      game = 0;
      break;
    case OPTIONS:
      game = 6; // paint
      loadImg(imgNum);
      break;
    }
  }
  if ((long(millis() - lastMove) > 200) && (buttons != NOTHING)) {
    switch (buttons) {
    case DOWN:
    case RIGHT:
    case START:
      if (imgNum < 3)
        imgNum++;
      else
        imgNum = 0;
      break;
    case UP:
    case LEFT:
      if (imgNum)
        imgNum--;
      else
        imgNum = 3;
      break;
    }
    loadImg(imgNum);
    lastMove = millis();
  }
  if (imgNum < 0) {
    imgNum = 0;
    loadImg(imgNum);
  }
  for (byte i = 0; i < 8; i++) {
    buffer1[i] = img1[i];
    buffer2[i] = img2[i];
  }
}


